import {
  extent,
  scaleLinear,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';
import { axisLeft, axisBottom } from 'd3';
const sectionColors = [
  		'aqua', 'turquoise', 'lime'];
// Script for the Axes
export const axes = (
  selection,
  {
    xScale,
    yScale,
    xAxisLabel,
    yAxisLabel,
    xAxisLabelOffset = 25,
    yAxisLabelOffset = 30,
  }
) => {
  selection
    .selectAll('g.y-axis')
    .data([null])
    .join('g')
    .attr('class', 'y-axis')
    .attr(
      'transform',
      `translate(${xScale.range()[0]},0)`
    )
    .call(axisLeft(yScale));

  selection
    .selectAll('g.x-axis')
    .data([null])
    .join('g')
    .attr('class', 'x-axis')
    .attr(
      'transform',
      `translate(0,${yScale.range()[0]})`
    )
    .call(axisBottom(xScale));
// Setting X-Axis Label
  selection
    .selectAll('text.x-axis-label')
    .data([null])
    .join('text')
    .attr(
      'x',
      (xScale.range()[0] + xScale.range()[1]) / 2
    )
    .attr(
      'y',
      yScale.range()[0] + xAxisLabelOffset
    )
    .attr('class', 'x-axis-label')
    .attr('alignment-baseline', 'hanging')
    .attr('text-anchor', 'middle')
    .attr('font-family', 'sans-serif')
    .text(xAxisLabel);
  
// Setting Y-Axis Label
  selection
    .selectAll('text.y-axis-label')
    .data([null])
    .join('text')
    .attr('class', 'y-axis-label')
    .attr('text-anchor', 'middle')
    .attr('transform', 'rotate(-90)')
    .attr('font-family', 'sans-serif')
    .attr(
      'x',
      -(yScale.range()[0] + yScale.range()[1]) / 2
    )
    .attr(
      'y',
      xScale.range()[0] - yAxisLabelOffset
    )
    .text(yAxisLabel);
};


// Script for the Scatter Plot
export const scatterPlot = (
  selection,
  {
    data,
    width,
    height,
    xValue,
    yValue,
    colorValue,
    margin,
    xAxisLabel,
    yAxisLabel,
    colorLegendLabel,
    colorLegendX,
    colorLegendY,
  }
) => {
  // Scaling X-axis based on the data
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([margin.left, width - margin.right]);

  // Scaling Y-axis based on the data
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([height - margin.bottom, margin.top]);

  const colorScale = scaleOrdinal()
    	.domain(data)
  	.range(sectionColors);


  selection.call(axes, {
    xScale,
    yScale,
    xAxisLabel,
    yAxisLabel,
  });


  selection
    .selectAll('circle.mark')
    .data(data)
    .join('circle')
    .attr('class', 'mark')
    .attr('cx', (d) => xScale(xValue(d)))
    .attr('cy', (d) => yScale(yValue(d)))
    .attr('fill', (d) =>
      colorScale(colorValue(d))
    )
    .attr('r', 10);
};
